@@ -1,14 +1,14 @@
 /***************************************************************************
  * LPRng - An Extended Print Spooler System
  *
- * Copyright 1988-2002, Patrick Powell, San Diego, CA
+ * Copyright 1988-2003, Patrick Powell, San Diego, CA
  *     papowell@lprng.com
  * See LICENSE for conditions of use.
  *
  ***************************************************************************/
 
  static char *const _id =
-"$Id: sendjob.c,v 1.46 2003/01/17 23:01:25 papowell Exp $";
+"$Id: sendjob.c,v 1.57 2003/09/05 20:07:20 papowell Exp $";
 
 
 #include "lp.h"
@@ -136,7 +136,7 @@ int Send_job( struct job *job, struct job *logjob,
 	errno = 0;
 
 	sock = Link_open_list( RemoteHost_DYN,
-		&real_host, 0, connect_timeout_len, 0, Unix_socket_path_DYN );
+		&real_host, connect_timeout_len, 0, Unix_socket_path_DYN );
 
 	err = errno;
 	DEBUG4("Send_job: socket %d", sock );
